import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FaAngleDoubleLeft, FaAngleDoubleRight, FaAngleLeft, FaAngleRight } from 'react-icons/fa';
import { getNoOfPages } from '../../utils/CommonUtils';
import '../.././datagrid.css';
/*
* The Pagination component for the grid which will  handle the renderPagination functionality for the grid.
 *
 * @type {class}*/
class Pagination extends Component {
  constructor(props) {
    super(props);
    this.renderPagination = this.renderPagination.bind(this);
    this.renderArrowLeft = this.renderArrowLeft.bind(this);
    this.renderArrowRight = this.renderArrowRight.bind(this);
    this.onPageDecrement = this.onPageDecrement.bind(this);
    this.onPageIncrement = this.onPageIncrement.bind(this);
    this.jumpToFirstPage = this.jumpToFirstPage.bind(this);
    this.jumpToLastPage = this.jumpToLastPage.bind(this);
  }

  renderPagination() {
    return (
      <div className="pagination-wrapper">
        {this.renderArrowLeft()}
        <span className="pagination-info">
          <span
            className="page-number"
          >Page: {this.props.currentPage}/{getNoOfPages(this.props.data, this.props.recordsPerPage)}
          </span>
        </span>
        {this.renderArrowRight()}
      </div>
    );
  }

  renderArrowLeft() {
    if (this.props.currentPage > 1) {
      return (
        <div className="page-number-arrow-for-margin">
          <button onClick={this.jumpToFirstPage} className="page-number-arrow">
            <FaAngleDoubleLeft className="arrowIcon" />
          </button>
          <button onClick={this.onPageDecrement} className="page-number-arrow">
            <FaAngleLeft className="arrowIcon" />
          </button>
        </div>
      );
    }
    return null;
  }

  renderArrowRight() {
    if (this.props.currentPage < getNoOfPages(this.props.data, this.props.recordsPerPage)) {
      return (
        <div className="page-number-arrow-for-margin">
          <button onClick={this.onPageIncrement} className="page-number-arrow">
            <FaAngleRight className="arrowIcon" />
          </button>
          <button onClick={this.jumpToLastPage} className="page-number-arrow">
            <FaAngleDoubleRight className="arrowIcon" />
          </button>
        </div>
      );
    }
    return null;
  }

  jumpToFirstPage() {
    this.props.onPagination('firstPage');
  }

  jumpToLastPage() {
    this.props.onPagination('lastPage');
  }

  onPageDecrement() {
    this.props.onPagination('decrement');
  }

  onPageIncrement() {
    this.props.onPagination('increment');
  }

  render() {
    return (
      <div>
        {this.renderPagination()}
      </div>
    );

  }
}
Pagination.propTypes = {
  data: PropTypes.array,
  onPagination: PropTypes.func.isRequired,
  currentPage: PropTypes.number,
  recordsPerPage: PropTypes.number,
};

Pagination.defaultProps = {
  data: [],
  currentPage: 0,
  recordsPerPage: 0,
};
export default Pagination;
